@@ -21,7 +21,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <stdio.h>
 #include <libgda/gda-client.h>
 #include <libgda/gda-config.h>
@@ -35,6 +34,7 @@
 struct _GdaConnectionPrivate {
 	GdaClient *client;
 	GdaServerProvider *provider_obj;
+	GdaConnectionOptions options;
 	gchar *dsn;
 	gchar *cnc_string;
 	gchar *provider;
@@ -129,6 +129,7 @@ gda_connection_finalize (GObject *object)
 	if (cnc->priv->is_open) {
 		/* close the connection to the provider */
 		gda_server_provider_close_connection (cnc->priv->provider_obj, cnc);
+		gda_client_notify_connection_closed_event (cnc->priv->client, cnc);
 	}
 
 	g_object_unref (G_OBJECT (cnc->priv->provider_obj));
@@ -150,6 +151,7 @@ gda_connection_finalize (GObject *object)
 	/* chain to parent class */
 	parent_class->finalize (object);
 }
+
 /**
  * gda_connection_get_type
  * 
@@ -185,6 +187,7 @@ gda_connection_get_type (void)
  * @dsn: GDA data source to connect to.
  * @username: user name to use to connect.
  * @password: password for @username.
+ * @options: options for the connection.
  *
  * This function creates a new #GdaConnection object. It is not
  * intended to be used directly by applications (use
@@ -197,7 +200,8 @@ gda_connection_new (GdaClient *client,
 		    GdaServerProvider *provider,
 		    const gchar *dsn,
 		    const gchar *username,
-		    const gchar *password)
+		    const gchar *password,
+		    GdaConnectionOptions options)
 {
 	GdaConnection *cnc;
 	GdaDataSourceInfo *dsn_info;
@@ -224,9 +228,9 @@ gda_connection_new (GdaClient *client,
 		if (dsn_info->username)
 			real_username = dsn_info->username;
 		else {
-			real_username = gda_quark_list_find (params, "USERNAME");
+			real_username = gda_quark_list_find (params, "USER");
 			if (real_username)
-				gda_quark_list_remove (params, "USERNAME");
+				gda_quark_list_remove (params, "USER");
 		}
 	}
 
@@ -253,6 +257,7 @@ gda_connection_new (GdaClient *client,
 	cnc->priv->provider = g_strdup (dsn_info->provider);
 	cnc->priv->username = g_strdup (real_username);
 	cnc->priv->password = g_strdup (real_password);
+	cnc->priv->options = options;
 
 	gda_config_free_data_source_info (dsn_info);
 
@@ -263,17 +268,24 @@ gda_connection_new (GdaClient *client,
 		GList *errors_copy;
 
 		errors_copy = gda_connection_get_errors (cnc);
-		/* emit the "error" signal on the GdaClient, since
-		   that's the only way we can notify it of errors */
+		/* notify the GdaClient of the error, since
+		   that's the only way we can notify it of errors
+		   when creating the connection */
 		if (errors_copy) {
-			g_signal_emit_by_name (G_OBJECT (client), "error",
-					       cnc, errors_copy);
+			GList *l;
+
+			for (l = errors_copy; l != NULL; l = l->next)
+				gda_client_notify_error_event (client, cnc, GDA_ERROR (l->data));
 		}
 		gda_quark_list_free (params);
 		g_object_unref (G_OBJECT (cnc));
 		return NULL;
 	}
 
+	/* notify action */
+	gda_client_notify_connection_opened_event (client, cnc);
+
+	/* free memory */
 	gda_quark_list_free (params);
 	cnc->priv->is_open = TRUE;
 
@@ -349,6 +361,21 @@ gda_connection_set_client (GdaConnection *cnc, GdaClient *client)
 	cnc->priv->client = client;
 }
 
+/**
+ * gda_connection_get_options
+ * @cnc: a #GdaConnection object.
+ *
+ * Get the #GdaConnectionOptions used to open this connection.
+ *
+ + Returns: the connection options.
+*/
+GdaConnectionOptions
+gda_connection_get_options (GdaConnection *cnc)
+{
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), -1);
+	return cnc->priv->options;
+}
+
 /**
  * gda_connection_get_server_version
  * @cnc: A #GdaConnection object.
@@ -480,7 +507,6 @@ gda_connection_add_error (GdaConnection *cnc, GdaError *error)
 
 	g_return_if_fail (GDA_IS_CONNECTION (cnc));
 	g_return_if_fail (GDA_IS_ERROR (error));
-	
 
 	err_list = cnc->priv->error_list;
 	gda_error_list_free (err_list);
@@ -742,8 +768,16 @@ gda_connection_execute_non_query (GdaConnection *cnc,
 gboolean
 gda_connection_begin_transaction (GdaConnection *cnc, GdaTransaction *xaction)
 {
+	gboolean retval;
+
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-	return gda_server_provider_begin_transaction (cnc->priv->provider_obj, cnc, xaction);
+	g_return_val_if_fail (GDA_IS_TRANSACTION (xaction), FALSE);
+
+	retval = gda_server_provider_begin_transaction (cnc->priv->provider_obj, cnc, xaction);
+	if (retval)
+		gda_client_notify_transaction_started_event (cnc->priv->client, cnc, xaction);
+
+	return retval;
 }
 
 /**
@@ -760,8 +794,16 @@ gda_connection_begin_transaction (GdaConnection *cnc, GdaTransaction *xaction)
 gboolean
 gda_connection_commit_transaction (GdaConnection *cnc, GdaTransaction *xaction)
 {
+	gboolean retval;
+
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-	return gda_server_provider_commit_transaction (cnc->priv->provider_obj, cnc, xaction);
+	g_return_val_if_fail (GDA_IS_TRANSACTION (xaction), FALSE);
+
+	retval = gda_server_provider_commit_transaction (cnc->priv->provider_obj, cnc, xaction);
+	if (retval)
+		gda_client_notify_transaction_committed_event (cnc->priv->client, cnc, xaction);
+
+	return retval;
 }
 
 /**
@@ -779,8 +821,16 @@ gda_connection_commit_transaction (GdaConnection *cnc, GdaTransaction *xaction)
 gboolean
 gda_connection_rollback_transaction (GdaConnection *cnc, GdaTransaction *xaction)
 {
+	gboolean retval;
+
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-	return gda_server_provider_rollback_transaction (cnc->priv->provider_obj, cnc, xaction);
+	g_return_val_if_fail (GDA_IS_TRANSACTION (xaction), FALSE);
+
+	retval = gda_server_provider_rollback_transaction (cnc->priv->provider_obj, cnc, xaction);
+	if (retval)
+		gda_client_notify_transaction_cancelled_event (cnc->priv->client, cnc, xaction);
+
+	return retval;
 }
 
 /**
