@@ -30,13 +30,13 @@ GdaServerProvider *plugin_create_provider (void);
 const gchar *
 plugin_get_name (void)
 {
-	return "Default";
+	return _("Default");
 }
 
 const gchar *
 plugin_get_description (void)
 {
-	return _("GDA default provider, based on the libgda XML format");
+	return _("Default provider, based on XML");
 }
 
 GList *
